if [ -x /usr/bin/gtk-update-icon-cache.exe ]
then
    /usr/bin/gtk-update-icon-cache --force /usr/share/icons/hicolor
fi

/usr/bin/update-desktop-database
/usr/bin/update-mime-database /usr/share/mime

